package edu.laura.temaValaszt.choose;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import edu.laura.temaValaszt.beans.ProjectBean;
import edu.laura.temaValaszt.beans.StudentBean;
import edu.laura.temaValaszt.beans.StudentToProjectBean;
import edu.laura.temaValaszt.dao.DAOFactory;
import edu.laura.temaValaszt.dao.ProjectDAO;
import edu.laura.temaValaszt.dao.StudentDAO;
import edu.laura.temaValaszt.dao.StudentToProjectDAO;

public class ChooseBL {
	
	interface PROJECT_STATUS {
		static final int PUBLIC = 1;
		static final int OWN = 2;
	}
	
	static boolean hasProject(Map<Integer, StudentBean> studentsForProjectMap, Integer personID) {
		if (studentsForProjectMap!=null) {
			for (StudentBean studentBean : studentsForProjectMap.values()) {
				if (studentBean.getObjectID().equals(personID)) {
					return true;
				}
			}
		}
		return false;
	}
	
	static Map<Integer, StudentBean> getStudentsForProjectMap() {
		Map<Integer, StudentBean> studentMap = getStudentsMap();
		List<StudentToProjectBean> studentToProjectBeans = 
			DAOFactory.getFactory().getStudentToProjectDAO().getAllAssignments();
		Map<Integer, StudentBean> studentForProjectMap = new HashMap<Integer, StudentBean>();
		for (StudentToProjectBean studentToProjectBean : studentToProjectBeans) {
			StudentBean studentBean = studentMap.get(studentToProjectBean.getStudentID());
			studentForProjectMap.put(studentToProjectBean.getProjectID(), studentBean);
		}
		return studentForProjectMap;
	}
	
	private static Map<Integer, StudentBean> getStudentsMap() {
		Map<Integer, StudentBean> studentMap = new HashMap<Integer, StudentBean>();
		StudentDAO studentDAO = DAOFactory.getFactory().getStudentDAO();
		List<StudentBean> studentBeans = studentDAO.getPersonsWithProject();
		for (StudentBean studentBean: studentBeans) {
			studentMap.put(studentBean.getObjectID(), studentBean);
		}
		return studentMap;
	}
	
    //visszateriti az osszes tema listajat:
	public static List<ProjectBean> getProjectList(Integer studentID){
		ProjectDAO projectDAO = DAOFactory.getFactory().getProjectDAO();
		return projectDAO.getAllProjects();		
		
	}
	
	//visszateriti a szabad temak listajat 
	public static List<ProjectBean> getUnassignedThemes(){
		ProjectDAO projectDAO = DAOFactory.getFactory().getProjectDAO();
		return projectDAO.getUnassignedProjects();
	}
	
	//torli a parameterkent megadott azonositoju felhasznalo valasztasat, illetve a temat is, ha azt a diak javasolta
	public static void remove(Integer studentID){
		StudentToProjectDAO studentToProjectDAO = DAOFactory.getFactory().getStudentToProjectDAO();
		StudentToProjectBean studentToProjectBean = studentToProjectDAO.loadByStudentID(studentID);
		if (studentToProjectBean!=null) {
			studentToProjectDAO.deleteByStudentID(studentID);
			Integer projectID = studentToProjectBean.getProjectID();
			ProjectDAO projectDAO = DAOFactory.getFactory().getProjectDAO();
			ProjectBean projectBean = projectDAO.loadByProjectID(projectID);
			if (projectBean!=null) {
				Integer status = projectBean.getStatus();
				if (status.equals(PROJECT_STATUS.OWN)) {
					projectDAO.removeByProjectID(projectID);
				}
			}
		}
	}
	
	
	// a studenttoproject tablaba beir egy uj bejegyzest
	//a StudentID azonositoju diak kivalasztotta a ProjectID azonositoju temat
	public static void assign(Integer studentID, Integer projectID){
		StudentToProjectBean studentToProjectBean = new StudentToProjectBean();
		studentToProjectBean.setProjectID(projectID);
		studentToProjectBean.setStudentID(studentID);
		StudentToProjectDAO studentToProjectDAO = DAOFactory.getFactory().getStudentToProjectDAO();
		studentToProjectDAO.assign(studentID, projectID);
	}
	
	
	//uj temat szur be a project tablaba
	public static void newTheme(String newProject, String newProjectDescription,Integer studentID){
		ProjectDAO projectDAO = DAOFactory.getFactory().getProjectDAO();
		ProjectBean projectBean = new ProjectBean();
		projectBean.setTitle(newProject);
		projectBean.setDescription(newProjectDescription);
		projectBean.setProposedBy(studentID);
		projectBean.setStatus(PROJECT_STATUS.OWN);
		Integer projectID = projectDAO.saveProject(projectBean);
		assign(studentID, projectID);
	}
}
